{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "qiime2: Visually and statistically compare groups of alpha diversity values",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "qiime2/core:2018.4",
                    "id": "#qiime2-docker-hint.yml",
                    "name": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "inputBinding": {
                        "prefix": "--i-alpha-diversity"
                    },
                    "label": "Vector of alpha diversity values by sample",
                    "type": "File",
                    "id": "#diversity-alpha-group-significance.cwl/alpha_diversity"
                },
                {
                    "inputBinding": {
                        "prefix": "--m-metadata-file"
                    },
                    "label": "Metadata file or artifact viewable as metadata",
                    "type": "File",
                    "id": "#diversity-alpha-group-significance.cwl/metadata_file"
                },
                {
                    "inputBinding": {
                        "prefix": "--o-visualization"
                    },
                    "label": "The resulting visualization filename",
                    "type": "string",
                    "id": "#diversity-alpha-group-significance.cwl/output_significance_filename"
                }
            ],
            "baseCommand": [
                "qiime",
                "diversity",
                "alpha-group-significance"
            ],
            "id": "#diversity-alpha-group-significance.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_significance_filename)"
                    },
                    "id": "#diversity-alpha-group-significance.cwl/significance"
                }
            ]
        },
        {
            "label": "qiime2: Determine whether groups of samples are significantly different from one another using a permutation-based statistical test",
            "class": "CommandLineTool",
            "hints": [
                {
                    "$import": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "inputBinding": {
                        "prefix": "--i-distance-matrix"
                    },
                    "label": "Matrix of distances between pairs of samples",
                    "type": "File",
                    "id": "#diversity-beta-group-significance.cwl/distance_matrix"
                },
                {
                    "inputBinding": {
                        "prefix": "--m-metadata-column"
                    },
                    "label": "Column from metadata file or artifact viewable as metadata",
                    "type": "string",
                    "id": "#diversity-beta-group-significance.cwl/metadata_column"
                },
                {
                    "inputBinding": {
                        "prefix": "--m-metadata-file"
                    },
                    "label": "Metadata file or artifact viewable as metadata",
                    "type": "File",
                    "id": "#diversity-beta-group-significance.cwl/metadata_file"
                },
                {
                    "inputBinding": {
                        "prefix": "--o-visualization"
                    },
                    "label": "resulting visualization filename",
                    "type": "string",
                    "id": "#diversity-beta-group-significance.cwl/output_significance_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_significance_filename)"
                    },
                    "id": "#diversity-beta-group-significance.cwl/out_visual"
                }
            ],
            "arguments": [
                {
                    "prefix": "--p-pairwise\""
                }
            ],
            "baseCommand": [
                "qiime",
                "diversity",
                "beta-group-significance"
            ],
            "id": "#diversity-beta-group-significance.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "qiime2: Applies a collection of diversity metrics (both phylogenetic and non-phylogenetic) to a feature table.",
            "baseCommand": [
                "qiime",
                "diversity",
                "core-metrics-phylogenetic"
            ],
            "hints": [
                {
                    "$import": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "inputBinding": {
                        "prefix": "--i-table"
                    },
                    "doc": "The feature table containing the samples over which diversity metrics should be computed",
                    "type": "File",
                    "id": "#diversity-core-metrics-phylogenetic.cwl/input_table"
                },
                {
                    "inputBinding": {
                        "prefix": "--i-phylogeny"
                    },
                    "label": "Phylogenetic tree containing tip identifiers that correspond to the feature identifiers in the table",
                    "type": "File",
                    "id": "#diversity-core-metrics-phylogenetic.cwl/input_tree"
                },
                {
                    "inputBinding": {
                        "prefix": "--m-metadata-file"
                    },
                    "label": "Metadata file or artifact viewable as metadata",
                    "type": "File",
                    "id": "#diversity-core-metrics-phylogenetic.cwl/metadata_file"
                },
                {
                    "inputBinding": {
                        "prefix": "--output-dir"
                    },
                    "type": "string",
                    "label": "name of the directory to contain the results",
                    "default": "core-metrics-results",
                    "id": "#diversity-core-metrics-phylogenetic.cwl/output_dir_name"
                },
                {
                    "inputBinding": {
                        "prefix": "--p-sampling-depth"
                    },
                    "label": "The total frequency that each sample should be rarefied to prior to computing diversity metrics",
                    "type": "int",
                    "default": 1080,
                    "id": "#diversity-core-metrics-phylogenetic.cwl/sampling_depth"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_dir_name + '/bray_curtis_pcoa_results.qza')"
                    },
                    "id": "#diversity-core-metrics-phylogenetic.cwl/bray_curtis_pcoa_results"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_dir_name + '/evenness_vector.qza')"
                    },
                    "id": "#diversity-core-metrics-phylogenetic.cwl/evenness_vector"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_dir_name + '/faith_pd_vector.qza')"
                    },
                    "id": "#diversity-core-metrics-phylogenetic.cwl/faith_pd_vector"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.output_dir_name)"
                    },
                    "id": "#diversity-core-metrics-phylogenetic.cwl/out_dir"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_dir_name + '/unweighted_unifrac_distance_matrix.qza')"
                    },
                    "id": "#diversity-core-metrics-phylogenetic.cwl/unweighted_unifrac_distance_matrix"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_dir_name + '/unweighted_unifrac_pcoa_results.qza')"
                    },
                    "id": "#diversity-core-metrics-phylogenetic.cwl/unweighted_unifrac_pcoa_results"
                }
            ],
            "id": "#diversity-core-metrics-phylogenetic.cwl"
        },
        {
            "label": "qiime2: emperor visualization and ordination",
            "class": "CommandLineTool",
            "hints": [
                {
                    "$import": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "label": "Name for custom axis label",
                    "inputBinding": {
                        "prefix": "--p-custom-axes"
                    },
                    "type": "string",
                    "id": "#emperor-plot.cwl/custom_axes"
                },
                {
                    "inputBinding": {
                        "prefix": "--m-metadata-file"
                    },
                    "label": "Metadata file or artifact viewable as metadata",
                    "type": "File",
                    "id": "#emperor-plot.cwl/metadata_file"
                },
                {
                    "label": "resulting visualization filename",
                    "inputBinding": {
                        "prefix": "--o-visualization"
                    },
                    "type": "string",
                    "id": "#emperor-plot.cwl/out_visualization"
                },
                {
                    "inputBinding": {
                        "prefix": "--i-pcoa"
                    },
                    "label": "The principal coordinates matrix to be plotted",
                    "type": "File",
                    "id": "#emperor-plot.cwl/pcoa"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.out_visualization)"
                    },
                    "id": "#emperor-plot.cwl/pcoa_visual"
                }
            ],
            "baseCommand": [
                "qiime",
                "emperor",
                "plot"
            ],
            "id": "#emperor-plot.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "label": "qiime2 diversity analyses",
            "doc": "Alpha and beta diversity analysis from https://docs.qiime2.org/2018.4/tutorials/moving-pictures/",
            "inputs": [
                {
                    "type": "string",
                    "default": "bray-curtis-emperor-DaysSinceExperimentStart.qzv",
                    "id": "#main/bray_curtis_emperor_filename"
                },
                {
                    "type": "string",
                    "default": "evenness-group-significance.qzv",
                    "id": "#main/evenness_group_significance_filename"
                },
                {
                    "type": "string",
                    "default": "faith-pd-group-significance.qzv",
                    "id": "#main/faith_pd_group_significance_filename"
                },
                {
                    "type": "File",
                    "id": "#main/rooted_tree"
                },
                {
                    "type": "File",
                    "id": "#main/sample_metadata"
                },
                {
                    "type": "int",
                    "id": "#main/sampling_depth"
                },
                {
                    "type": "File",
                    "id": "#main/table"
                },
                {
                    "type": "string",
                    "default": "unweighted-unifrac-body-site-significance.qzv",
                    "id": "#main/unweighted_unifrac_body_site_significance_filename"
                },
                {
                    "type": "string",
                    "default": "unweighted-unifrac-emperor-DaysSinceExperimentStart.qzv",
                    "id": "#main/unweighted_unifrac_emperor_filename"
                },
                {
                    "type": "string",
                    "default": "unweighted-unifrac-subject-group-significance.qzv",
                    "id": "#main/unweighted_unifrac_subject_group_significance_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/bray_curtis_emperor/pcoa_visual",
                    "id": "#main/bray_curtis_emperor_file"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/generate_core_metrics/out_dir",
                    "id": "#main/core_metrics_directory"
                },
                {
                    "type": "File",
                    "outputSource": "#main/evenness_group_significance/significance",
                    "id": "#main/evenness_group_significance_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/faith_pd_group_significance/significance",
                    "id": "#main/faith_pd_group_significance_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unweighted_unifrac_body_site_significance/out_visual",
                    "id": "#main/unweighted_unifrac_body_site_significance_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unweighted_unifrac_emperor/pcoa_visual",
                    "id": "#main/unweighted_unifrac_emperor_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unweighted_unifrac_subject_group_significance/out_visual",
                    "id": "#main/unweighted_unifrac_subject_group_significance_file"
                }
            ],
            "steps": [
                {
                    "run": "#emperor-plot.cwl",
                    "in": [
                        {
                            "valueFrom": "DaysSinceExperimentStart",
                            "id": "#main/bray_curtis_emperor/custom_axes"
                        },
                        {
                            "source": "#main/sample_metadata",
                            "id": "#main/bray_curtis_emperor/metadata_file"
                        },
                        {
                            "source": "#main/bray_curtis_emperor_filename",
                            "id": "#main/bray_curtis_emperor/out_visualization"
                        },
                        {
                            "source": "#main/generate_core_metrics/bray_curtis_pcoa_results",
                            "id": "#main/bray_curtis_emperor/pcoa"
                        }
                    ],
                    "out": [
                        "#main/bray_curtis_emperor/pcoa_visual"
                    ],
                    "id": "#main/bray_curtis_emperor"
                },
                {
                    "run": "#diversity-alpha-group-significance.cwl",
                    "in": [
                        {
                            "source": "#main/generate_core_metrics/evenness_vector",
                            "id": "#main/evenness_group_significance/alpha_diversity"
                        },
                        {
                            "source": "#main/sample_metadata",
                            "id": "#main/evenness_group_significance/metadata_file"
                        },
                        {
                            "source": "#main/evenness_group_significance_filename",
                            "id": "#main/evenness_group_significance/output_significance_filename"
                        }
                    ],
                    "out": [
                        "#main/evenness_group_significance/significance"
                    ],
                    "id": "#main/evenness_group_significance"
                },
                {
                    "run": "#diversity-alpha-group-significance.cwl",
                    "in": [
                        {
                            "source": "#main/generate_core_metrics/faith_pd_vector",
                            "id": "#main/faith_pd_group_significance/alpha_diversity"
                        },
                        {
                            "source": "#main/sample_metadata",
                            "id": "#main/faith_pd_group_significance/metadata_file"
                        },
                        {
                            "source": "#main/faith_pd_group_significance_filename",
                            "id": "#main/faith_pd_group_significance/output_significance_filename"
                        }
                    ],
                    "out": [
                        "#main/faith_pd_group_significance/significance"
                    ],
                    "id": "#main/faith_pd_group_significance"
                },
                {
                    "run": "#diversity-core-metrics-phylogenetic.cwl",
                    "in": [
                        {
                            "source": "#main/table",
                            "id": "#main/generate_core_metrics/input_table"
                        },
                        {
                            "source": "#main/rooted_tree",
                            "id": "#main/generate_core_metrics/input_tree"
                        },
                        {
                            "source": "#main/sample_metadata",
                            "id": "#main/generate_core_metrics/metadata_file"
                        },
                        {
                            "source": "#main/sampling_depth",
                            "id": "#main/generate_core_metrics/sampling_depth"
                        }
                    ],
                    "out": [
                        "#main/generate_core_metrics/out_dir",
                        "#main/generate_core_metrics/faith_pd_vector",
                        "#main/generate_core_metrics/evenness_vector",
                        "#main/generate_core_metrics/unweighted_unifrac_distance_matrix",
                        "#main/generate_core_metrics/unweighted_unifrac_pcoa_results",
                        "#main/generate_core_metrics/bray_curtis_pcoa_results"
                    ],
                    "id": "#main/generate_core_metrics"
                },
                {
                    "run": "#diversity-beta-group-significance.cwl",
                    "in": [
                        {
                            "source": "#main/generate_core_metrics/unweighted_unifrac_distance_matrix",
                            "id": "#main/unweighted_unifrac_body_site_significance/distance_matrix"
                        },
                        {
                            "valueFrom": "BodySite",
                            "id": "#main/unweighted_unifrac_body_site_significance/metadata_column"
                        },
                        {
                            "source": "#main/sample_metadata",
                            "id": "#main/unweighted_unifrac_body_site_significance/metadata_file"
                        },
                        {
                            "source": "#main/unweighted_unifrac_body_site_significance_filename",
                            "id": "#main/unweighted_unifrac_body_site_significance/output_significance_filename"
                        }
                    ],
                    "out": [
                        "#main/unweighted_unifrac_body_site_significance/out_visual"
                    ],
                    "id": "#main/unweighted_unifrac_body_site_significance"
                },
                {
                    "run": "#emperor-plot.cwl",
                    "in": [
                        {
                            "valueFrom": "DaysSinceExperimentStart",
                            "id": "#main/unweighted_unifrac_emperor/custom_axes"
                        },
                        {
                            "source": "#main/sample_metadata",
                            "id": "#main/unweighted_unifrac_emperor/metadata_file"
                        },
                        {
                            "source": "#main/unweighted_unifrac_emperor_filename",
                            "id": "#main/unweighted_unifrac_emperor/out_visualization"
                        },
                        {
                            "source": "#main/generate_core_metrics/unweighted_unifrac_pcoa_results",
                            "id": "#main/unweighted_unifrac_emperor/pcoa"
                        }
                    ],
                    "out": [
                        "#main/unweighted_unifrac_emperor/pcoa_visual"
                    ],
                    "id": "#main/unweighted_unifrac_emperor"
                },
                {
                    "run": "#diversity-beta-group-significance.cwl",
                    "in": [
                        {
                            "source": "#main/generate_core_metrics/unweighted_unifrac_distance_matrix",
                            "id": "#main/unweighted_unifrac_subject_group_significance/distance_matrix"
                        },
                        {
                            "valueFrom": "Subject",
                            "id": "#main/unweighted_unifrac_subject_group_significance/metadata_column"
                        },
                        {
                            "source": "#main/sample_metadata",
                            "id": "#main/unweighted_unifrac_subject_group_significance/metadata_file"
                        },
                        {
                            "source": "#main/unweighted_unifrac_subject_group_significance_filename",
                            "id": "#main/unweighted_unifrac_subject_group_significance/output_significance_filename"
                        }
                    ],
                    "out": [
                        "#main/unweighted_unifrac_subject_group_significance/out_visual"
                    ],
                    "id": "#main/unweighted_unifrac_subject_group_significance"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
